Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(638)

Unified Diff: components/password_manager/core/browser/password_manager_metrics_util.h

Issue 2012723002: Add separate UMA histograms for the account chooser with 1/many accounts. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2743
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/password_manager/core/browser/password_manager_metrics_util.h
diff --git a/components/password_manager/core/browser/password_manager_metrics_util.h b/components/password_manager/core/browser/password_manager_metrics_util.h
index e6c8839cb9bc21b17cf703d717bef3afc4f201a9..e7b2ddbe893b1999bbfdbe5bfa92288b91c766a8 100644
--- a/components/password_manager/core/browser/password_manager_metrics_util.h
+++ b/components/password_manager/core/browser/password_manager_metrics_util.h
@@ -172,8 +172,9 @@ void LogMultiAccountUpdateBubbleUserAction(
// Log a user action on showing the autosignin first run experience.
void LogAutoSigninPromoUserAction(AutoSigninPromoUserAction action);
-// Log a user action on showing the account chooser.
-void LogAccountChooserUserAction(AccountChooserUserAction action);
+// Log a user action on showing the account chooser for one or many accounts.
+void LogAccountChooserUserActionOneAccount(AccountChooserUserAction action);
+void LogAccountChooserUserActionManyAccounts(AccountChooserUserAction action);
} // namespace metrics_util

Powered by Google App Engine
This is Rietveld 408576698